# Generated by roxygen2: do not edit by hand

export(.zmqopt_get)
export(.zmqopt_init)
export(.zmqopt_set)
export(ZMQ.MC)
export(ZMQ.PO)
export(ZMQ.SO)
export(ZMQ.SR)
export(ZMQ.ST)
export(address)
export(bind.socket)
export(connect.socket)
export(get.pbdZMQ.ldflags)
export(get.zmq.cppflags)
export(get.zmq.ldflags)
export(init.context)
export(init.socket)
export(ls)
export(overwrite.shpkg.rpath)
export(pbd_opt)
export(random_open_port)
export(random_port)
export(receive.socket)
export(send.socket)
export(test.load.zmq)
export(zmq.bind)
export(zmq.close)
export(zmq.connect)
export(zmq.ctx.destroy)
export(zmq.ctx.new)
export(zmq.disconnect)
export(zmq.getsockopt)
export(zmq.msg.recv)
export(zmq.msg.send)
export(zmq.poll)
export(zmq.poll.free)
export(zmq.poll.get.revents)
export(zmq.poll.length)
export(zmq.recv)
export(zmq.recv.multipart)
export(zmq.recvdir)
export(zmq.recvfile)
export(zmq.send)
export(zmq.send.multipart)
export(zmq.senddir)
export(zmq.sendfile)
export(zmq.setsockopt)
export(zmq.socket)
export(zmq.strerror)
export(zmq.version)
importFrom(stats,runif)
importFrom(utils,unzip)
importFrom(utils,zip)
