% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zmq.r
\name{C-like Wrapper Functions for ZeroMQ}
\alias{C-like Wrapper Functions for ZeroMQ}
\title{The C-like ZeroMQ Interface}
\description{
The basic interface to ZeroMQ that somewhat models the C interface.
}
\details{
A list of all functions for this interface is as follows:

\tabular{lll}{
\code{zmq.bind()} \tab \code{zmq.close()} \tab \code{zmqconnect()} \cr
\code{zmq.ctx.destroy()} \tab \code{zmq.ctx.new()} \tab \code{zmq.msg.recv()} \cr
\code{zmq.msg.send()} \tab \code{zmq.recv()} \tab \code{zmq.send()} \cr
\code{zmq.socket()} \tab \tab \cr
}
}
\references{
ZeroMQ/4.1.0 API Reference:
\url{https://libzmq.readthedocs.io/en/zeromq4-1/}

Programming with Big Data in R Website: \url{https://pbdr.org/}
}
\author{
Wei-Chen Chen \email{wccsnow@gmail.com}.
}
\keyword{zmq}
